/*
Demo of how to talk to a MySQL database from C.
Adds a record to the database.

Orion Sky Lawlor, olawlor@acm.org, 2006/04/12 (Public Domain)
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "config.h"

/*Build and connect to a mysql database.*/
MYSQL *connectSql(void) {
  MYSQL *mysql;

  mysql=(MYSQL *)malloc(sizeof(MYSQL));
  mysql_init(mysql);

  if (!mysql_connect(mysql,MYSQL_HOST,MYSQL_USERID,MYSQL_PASSWD))
  {
    printf("ERROR: Failed to connect to database: %s\n",mysql_error(mysql));
    exit(1);
  }

  if (mysql_select_db(mysql,MYSQL_DB)) {
    printf("ERROR: Failed to select database: %s\n",mysql_error(mysql));
    exit(1);
  }  
  return mysql;
}

/* Insert this data into the table */
const char *uploadMessage(MYSQL *mysql,const char *user,const char *msg)
{
  MYSQL_RES *result;
  char *query;

  /*Prepare the query*/
  query=(char *)malloc(strlen(user)+strlen(msg)+100);
  sprintf(query,"INSERT INTO log (importance,user,item) "
	"VALUES (0,'");
  
  /*Copy strings into the query, escaping any dangerous characters.
    This avoids big trouble if the message has a close-quote. */
  mysql_real_escape_string(mysql,&query[strlen(query)],user,strlen(user));
  strcat(query,"','");
  mysql_real_escape_string(mysql,&query[strlen(query)],msg,strlen(msg));
  strcat(query,"');");

  printf("Executing query: \n  %s\n",query);
  
  if (0!=mysql_query(mysql,query)) {
    printf("ERROR: During log record: %s\n",mysql_error(mysql));
  }
  result=mysql_store_result(mysql);
  if (result!=NULL) return "Non-null result from INSERT?";

  free(query);
  return NULL;
}



int main(int argc,char *argv[]) {
  MYSQL *mysql;
  char *user=argv[1];
  char *msg=argv[2];
  const char *result;

  if (argc!=3) {
	printf("ERROR: Usage: dbase <user> <msg>\n");
	exit(1);
  }
  mysql=connectSql();

  result=uploadMessage(mysql,user,msg);
  if (result!=NULL) {
    printf("ERROR: %s\n",result);
  }
  
  mysql_close(mysql);

  return 0;
}

